@@ -1,7 +1,9 @@
-import urllib.request
+import urllib.request, logging
 
 from .exceptions import *
 from .general import *
+from .output import log
+from .storage import storage
 
 def filter_mirrors_by_region(regions, destination='/etc/pacman.d/mirrorlist', tmp_dir='/root', *args, **kwargs):
 	"""
@@ -14,7 +16,7 @@ def filter_mirrors_by_region(regions, destination='/etc/pacman.d/mirrorlist', tm
 	region_list = []
 	for region in regions.split(','):
 		region_list.append(f'country={region}')
-	o = b''.join(sys_command((f"/usr/bin/wget 'https://www.archlinux.org/mirrorlist/?{'&'.join(region_list)}&protocol=https&ip_version=4&ip_version=6&use_mirror_status=on' -O {tmp_dir}/mirrorlist")))
+	o = b''.join(sys_command((f"/usr/bin/wget 'https://archlinux.org/mirrorlist/?{'&'.join(region_list)}&protocol=https&ip_version=4&ip_version=6&use_mirror_status=on' -O {tmp_dir}/mirrorlist")))
 	o = b''.join(sys_command((f"/usr/bin/sed -i 's/#Server/Server/' {tmp_dir}/mirrorlist")))
 	o = b''.join(sys_command((f"/usr/bin/mv {tmp_dir}/mirrorlist {destination}")))
 	
@@ -57,7 +59,7 @@ def insert_mirrors(mirrors, *args, **kwargs):
 	return True
 
 def use_mirrors(regions :dict, destination='/etc/pacman.d/mirrorlist'):
-	log(f'A new package mirror-list has been created: {destination}')
+	log(f'A new package mirror-list has been created: {destination}', level=logging.INFO)
 	for region, mirrors in regions.items():
 		with open(destination, 'w') as mirrorlist:
 			for mirror in mirrors:
@@ -71,23 +73,28 @@ def re_rank_mirrors(top=10, *positionals, **kwargs):
 	return False
 
 def list_mirrors():
-	url = f"https://www.archlinux.org/mirrorlist/?protocol=https&ip_version=4&ip_version=6&use_mirror_status=on"
-
-	response = urllib.request.urlopen(url)
+	url = f"https://archlinux.org/mirrorlist/?protocol=https&ip_version=4&ip_version=6&use_mirror_status=on"
 	regions = {}
 
+	try:
+		response = urllib.request.urlopen(url)
+	except urllib.error.URLError as err:
+		log(f'Could not fetch an active mirror-list: {err}', level=logging.WARNING, fg="yellow")
+		return regions
+
+
 	region = 'Unknown region'
 	for line in response.readlines():
-		if len(line.strip()) == 0: continue
+		if len(line.strip()) == 0:
+			continue
 
 		line = line.decode('UTF-8').strip('\n').strip('\r')
 		if line[:3] == '## ':
 			region = line[3:]
 		elif line[:10] == '#Server = ':
-			if not region in regions:
-				regions[region] = {}
+			regions.setdefault(region, {})
 
-			url = line[1:].lstrip('Server = ')
+			url = line.lstrip('#Server = ')
 			regions[region][url] = True
 
 	return regions
\ No newline at end of file
