@@ -14,6 +14,9 @@ storage = {
 		os.path.join(os.path.dirname(os.path.abspath(__file__)), 'profiles'),
 		#os.path.abspath(f'{os.path.dirname(__file__)}/../examples')
 	],
-	'UPSTREAM_URL' : 'https://raw.githubusercontent.com/Torxed/archinstall/master/profiles',
-	'PROFILE_DB' : None # Used in cases when listing profiles is desired, not mandatory for direct profile grabing.
+	'UPSTREAM_URL' : 'https://raw.githubusercontent.com/archlinux/archinstall/master/profiles',
+	'PROFILE_DB' : None, # Used in cases when listing profiles is desired, not mandatory for direct profile grabing.
+	'LOG_PATH' : '/var/log/archinstall',
+	'LOG_FILE' : 'install.log',
+	'MOUNT_POINT' : '/mnt'
 }
